%define current_version 2.5.0
%define cur_release 31

%define vz_suffix -vz

%global pkgsuffix %{vz_suffix}
%global obsoletes_version 15:0-0

%define semodules_dir %{_datadir}/selinux/packages

# Macro to properly setup conflict handling
%define vz_obsoletes() \
Provides: %1 = %{version}-%{release} \
Obsoletes: %1 < %{obsoletes_version}

Summary: QEMU guest agent
Name: qemu-guest-agent%{?pkgsuffix}
Version: %{current_version}
Release: %{cur_release}.el7
License: GPLv2+ and LGPLv2+ and BSD
Group: System Environment/Daemons
Group: Development/Tools
URL: http://www.qemu.org/
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units
%vz_obsoletes qemu-guest-agent

Source0: http://wiki.qemu.org/download/qemu-%{version}.tar.bz2

Source10: qemu-guest-agent.service
Source11: 99-qemu-guest-agent.rules
Source13: qemu-ga.sysconfig
Source14: virt_vz.te

BuildRequires: zlib-static
BuildRequires: glibc-static
BuildRequires: glib2-static
BuildRequires: SDL-devel
BuildRequires: which
BuildRequires: texi2html
BuildRequires: gnutls-devel
BuildRequires: cyrus-sasl-devel
BuildRequires: libtool
BuildRequires: libaio-devel
BuildRequires: rsync
BuildRequires: python
BuildRequires: pciutils-devel
BuildRequires: pulseaudio-libs-devel
BuildRequires: libiscsi-devel
BuildRequires: ncurses-devel
BuildRequires: libattr-devel
BuildRequires: pixman-devel
BuildRequires: selinux-policy-devel

%description
qemu-kvm is an open source virtualizer that provides hardware emulation for
the KVM hypervisor. 

This package provides an agent to run inside guests, which communicates
with the host over a virtio-serial channel named "org.qemu.guest_agent.0"

This package does not need to be installed on the host OS.

%prep
%setup -q -n qemu-%{version}

%build

./configure \
        --prefix=%{_prefix} \
        --libdir=%{_libdir} \
        --sysconfdir=%{_sysconfdir} \
        --localstatedir=%{_localstatedir} \
        --libexecdir=%{_libexecdir} \
        --with-pkgversion=%{name}-%{version}-%{release} \
        --target-list= --cpu=%{_arch} \
        --disable-fdt \
        --enable-guest-agent \
	--disable-pie \
        --static

# -Werror due to static linkage
make qemu-ga %{?_smp_mflags} -Werror

# selinux stuff
install -m 644 %SOURCE14 $RPM_BUILD_DIR/qemu-%{version}

make -f /usr/share/selinux/devel/Makefile virt_vz.pp

%install
%define _udevdir %(pkg-config --variable=udevdir udev)/rules.d

# For the qemu-guest-agent subpackage, install:
# - the systemd service file and the udev rules:
mkdir -p $RPM_BUILD_ROOT%{_unitdir}
mkdir -p $RPM_BUILD_ROOT%{_udevdir}
install -m 0644 %{SOURCE10} $RPM_BUILD_ROOT%{_unitdir}
install -m 0644 %{SOURCE11} $RPM_BUILD_ROOT%{_udevdir}

# - the environment file for the systemd service:
install -D -p -m 0644 %{SOURCE13} \
  $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/qemu-ga

# - the fsfreeze hook script:
install -D --preserve-timestamps \
  scripts/qemu-guest-agent/fsfreeze-hook \
  $RPM_BUILD_ROOT%{_sysconfdir}/qemu-ga/fsfreeze-hook

# - the directory for user scripts:
mkdir $RPM_BUILD_ROOT%{_sysconfdir}/qemu-ga/fsfreeze-hook.d

# - and the fsfreeze script samples:
mkdir --parents $RPM_BUILD_ROOT%{_datadir}/%{name}/qemu-ga/fsfreeze-hook.d/
install --preserve-timestamps --mode=0644 \
  scripts/qemu-guest-agent/fsfreeze-hook.d/*.sample \
  $RPM_BUILD_ROOT%{_datadir}/%{name}/qemu-ga/fsfreeze-hook.d/

# - Install dedicated log directory:
mkdir -p -v $RPM_BUILD_ROOT%{_localstatedir}/log/qemu-ga/

mkdir -p $RPM_BUILD_ROOT%{_bindir}
install -c -m 0755  qemu-ga ${RPM_BUILD_ROOT}%{_bindir}/qemu-ga

# Selinux stuff
mkdir -p ${RPM_BUILD_ROOT}%semodules_dir
install -m 644 virt_vz.pp ${RPM_BUILD_ROOT}%semodules_dir

%post
# Selinux
%{_sbindir}/semodule -n -s targeted -i %semodules_dir/virt_vz.pp > /dev/null 2>&1
if %{_sbindir}/selinuxenabled ; then
	%{_sbindir}/load_policy > /dev/null 2>&1
fi

# Workaround for chpasswd selinux domain
chcon -t passwd_exec_t /usr/sbin/chpasswd > /dev/null 2>&1

# Update udev rules
%udev_rules_update

# Reload systemd daemon
/usr/bin/systemctl daemon-reload >/dev/null 2>&1

# Always enable
/usr/bin/systemctl enable qemu-guest-agent.service >/dev/null 2>&1

# Always start
/usr/bin/systemctl start qemu-guest-agent.service >/dev/null 2>&1
:

%preun
%systemd_preun qemu-guest-agent.service

%postun
%systemd_postun_with_restart qemu-guest-agent.service

%files
%defattr(-,root,root,-)
%doc COPYING README
%{_bindir}/qemu-ga
%{_unitdir}/qemu-guest-agent.service
%{_udevdir}/99-qemu-guest-agent.rules
%{_sysconfdir}/sysconfig/qemu-ga
%{_sysconfdir}/qemu-ga
%{_datadir}/%{name}/qemu-ga
%dir %{_localstatedir}/log/qemu-ga
%semodules_dir

%changelog
* Wed Aug 17 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-31
- Ignore EBUSY for fsfreeze call #PSBM-50465

* Wed Aug 17 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-30
- Return statvfs() fsinfo on posix - #PSBM-43139
- Dont return error if cant parse slave virtual device link - #PSBM-43139

* Fri Jun 24 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-29
- Added requirement for network.target, see #PSBM-48833

* Fri May 27 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-28
- Moved VSS registration out of installer scope into agent #PSBM-47558

* Mon May 23 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-27
- Implemented guest-exec-terminate #PSBM-45383
- Added win32 event logging to qemu-ga.exe
- Translate glib log levels to system levels (syslog or windows event)
- Added custom syslog level mask

* Wed Mar 30 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-25
- Fixed a number of errors triggered by guest process termination before
  all stdin data sinked, #PSBM-45094
- generic code cleanup and small bugfixes. For #PSBM-43913 and #PSBM-44768

* Fri Mar  4 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-24
- Fixed dup message from  bad code in flush of aux channel, see #PSBM-44768

* Tue Feb 23 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-24
- Fix lost of default interface configuration in NM, see #PSBM-44508

* Wed Feb 17 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-22
- Updated Linux guest exec shell quoting rules - #PSBM-44045

* Tue Feb  9 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-20
- Fixed memleak of aux output channels used with sync write codepath.
  Issue #PSBM-43996

* Sat Feb  6 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-19
- Preliminary support for interactive shell. For #PSBM-40821

* Thu Feb  4 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-18
- Fixed default aux channel path not set if main channel path was
  specificed from command line, see #PSBM-40821

* Wed Feb  3 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-17
- Seekable chr dev glib workaround, see #PSBM-40821

* Wed Dec 30 2015 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-16
- Quote shell args for execute-in-shell on linux (#PSBM-42726)

* Tue Dec  8 2015 Konstantin Volkov <wolf@odin.com> - 2.5.0-15
- Filled [Install] section, see #PSBM-42105

* Mon Dec  7 2015 Konstantin Volkov <wolf@odin.com> - 2.5.0-14
- Limited guest-exec stdout/stderr data to maximum supported by
  libvirt xdr rpc for #PSBM-42041

* Fri Dec  4 2015 Konstantin Volkov <wolf@odin.com> - 2.5.0-13
- Change systemd service requires, see #PSBM-41913

* Fri Dec  4 2015 Konstantin Volkov <wolf@odin.com> - 2.5.0-12
- guest-set-user-password - added ability to create new user

* Thu Dec  3 2015 Konstantin Volkov <wolf@odin.com> - 2.5.0-11
- Update udev rules and reload systemd daemon at the end of installation, see #PSBM-41913

* Tue Dec  1 2015 Konstantin Volkov <wolf@odin.com> - 2.5.0-10
- Added guest-exec - new 'execute-in-shell' option

* Thu Nov 26 2015 Konstantin Volkov <wolf@odin.com> - 2.5.0-9
- Set permissive domain, see #PSBM-41596

* Fri Nov 20 2015 Konstantin Volkov <wolf@odin.com> - 2.5.0-7
- Added prl_nettool selinux support

* Thu Nov 19 2015 Konstantin Volkov <wolf@odin.com> - 2.5.0-6
- Added selinux support

* Mon Nov 16 2015 Konstantin Volkov <wolf@odin.com> - 2.5.0-5
- Removed libusbx-devel requires

* Mon Nov 16 2015 Konstantin Volkov <wolf@odin.com> - 2.5.0-4
- Removed Conflicts: qemu-guest-agent

* Thu Nov 12 2015 Konstantin Volkov <wolf@odin.com> - 2.5.0-2
- Added postun qga restart call

* Thu Oct 15 2015 Konstantin Volkov <wolf@odin.com> - 2.5.0-1
- Initial release
